c     Copyright (C)
c     2000 -2013 Universite Paul Sabatier,
c     2000 -2013 Centre National de la Recherche Scientifique
c     2000 -2013 Ecole des Mines d'Albi
c     2014-2018 Msostar
c
c     This program is free software; you can redistribute it and/or modify
c     it under the terms of the GNU General Public License as published by
c     the Free Software Foundation; either version 2, or (at your option)
c     any later version.

c     This program is distributed in the hope that it will be useful,
c     but WITHOUT ANY WARRANTY; without even the implied warranty of
c     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
c     GNU General Public License for more details.

c     You should have received a copy of the GNU General Public License
c     along with this program; if not, write to the Free Software
c     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
c     USA.
c
      subroutine read_pres2(m2,pres2,pres_gcm)
      implicit none
      include 'max.inc'
      include 'data.inc'
      include 'param.inc'
      include 'files_in.inc'
c     Purpose: to read the final pressure vertical mesh in file 'meshGCM.txt'
c     that will override the mesh that is provided in the main
c     data file.
c     Input: none
c     Output:
c       + m2 : number of atmospheric layers in pressure grid "pres2"
c       + pres2: pressure grid, containing m2+1 pressure levels.

      integer i,j,m2
      double precision pres2(0:Nmax)
      double precision pres_gcm(0:Nmax)
      double precision pres_inter(0:Nmax)
      double precision pres_cent(1:Nmax)
      
      open(11,file=file_meshGCM)
      call screen(34,0,0,0.0D+0,0.0D+0)
      
      read(11,*)
      read(11,*)
      read(11,*)
      i=0
      pres_inter(0)=1.0D+0
      do while (pres_inter(i).ne.0.0D+0)
         read(11,*) i,pres_inter(i)
      enddo
      m2=i
c     Debug
c      write(*,*) 'm2=',m2
c      stop
c     Debug
c     m2 est le nombre de valeurs de pres_inter fournies dans le fichier
c     -> ce qui nous donne m2-1 mailles

      rewind(11)
      read(11,*)
      read(11,*)
      read(11,*)
      do i=0,m2-2
         read(11,*) j,pres_inter(i),pres_cent(i+1)
      enddo
      read(11,*) j,pres_inter(m2-1)
      close(11)
c     Debug
c      do i=0,m2-1
c         write(*,*) 'pres_inter(',i,')=',pres_inter(i)
c      enddo
c      do i=1,m2-1
c         write(*,*) 'pres_cent(',i,')=',pres_cent(i)
c      enddo
c      stop
c     Debug

c     Vrification de cohrence du fichier de pression
      do i=1,m2-1
         if (pres_inter(i).gt.pres_inter(i-1)) then
            call screen(1143,i,0,pres_inter(i),pres_inter(i-1))
            stop
         endif
      enddo

c     Si la pression est nulle (en pratique, c'est toujours le cas pour
c     la dernire pression du fichier puisque c'est avec cette valeur nulle
c     qu'on repre la fin du fichier), on recalcule cette pression 
c     partir du rapport des deux derniers niveaux non nuls.
c     comment le 06/12/2006
      do i=0,m2-1
         if (pres_inter(i).eq.0.0D+0) then
c     Debug
c            write(*,*) 'i=',i,' pres_inter(',i,')=',pres_inter(i)
c     Debug
            pres_inter(i)=pres_inter(i-1)*
     &           pres_inter(i-1)/pres_inter(i-2)
c     Debug
c            write(*,*) 'i=',i,' pres2(',i,')=',pres2(i)
c            stop
c     Debug
         endif
      enddo
c     comment le 06/12/2006

c     06/12/2006
c     Tout a est trs beau. Il n'y a qu'un seul GROS problme:  partir de l,
c     m2 est le nombre de niveaux issu du maillage GCM (51 si 50 est le nombre
c     de mailles atmosphriques GCM). Dans la phase suivante, toutes les donnes
c     spectrales vont tre interpoles sur ce maillage comprenant m2-1 (=50)
c     mailles. Ensuite, le tableau "e" calcul  partir de ce maillage en pression
c     va comporter une maille de plus, soit m2 (51). Or on veut absolument que
c     les rsultats soient donns pour la grille de pression GCM ! En d'autres termes,
c     les pressions d'interfaces donnes par la grille GCM doivent galement tre
c     les pressions des interfaces pour le maillage de calcul "e".
c
c     Solution: utiliser les pressions "pres_cent" pour recaler le maillage en pression
c     "pres2", de telle faon que le maillage final "e" corresponde aux niveaux
c     de pression "pres_inter" (maillage en pression du GCM, souhait).

c     08/02/2007
c      pres2(0)=pres_inter(1)
      pres2(0)=pres_inter(0)
c     08/02/2007
      do i=1,m2-3
         pres2(i)=pres_cent(i+1)
      enddo
      pres2(m2-2)=pres_inter(m2-1)
c     Debug
c      do i=0,m2-2
c         write(*,*) 'pres2(',i,')=',pres2(i)
c      enddo
c      stop
c     Debug

c     On sort galement le tableau "pres_gcm", o les niveaux de pression correspondent
c     aux altitudes du tableau "e2".
      do i=0,m2-2
         pres_gcm(i)=pres_inter(i)
      enddo
      if (pres_inter(m2-1).le.0.0D+0) then
         pres_gcm(m2-1)=pres_cent(m2-1)
      else
         pres_gcm(m2-1)=pres_inter(m2-1)
      endif
c     Debug
c      do i=0,m2-1
c         write(*,*) 'pres_gcm(',i,')=',pres_gcm(i)
c      enddo
c      stop
c     Debug
c     Il n'y a plus que "m2" (51) interfaces dans le tableau "e2", soit "m2-1" (50) mailles.

c     "m2" est le nombre d'interfaces donnes dans le maillage GCM (51)
c     Le maillage "pres2" contient maintenant "m2-1" (50) interfaces, de faon  ce que
c     le tableau "e2" calcul  l'tape suivante contienne "m2" (51) interfaces. Il faut
c     renvoyer dans la variable 'm2' le nombre d'interfaces du maillage "pres2", soit "m2-1".
      m2=m2-1
c     Debug
c      write(*,*) 'm2=',m2
c      do i=0,m2-1
c         write(*,*) 'pres2(',i,')=',pres2(i)
c      enddo
c      stop
c     Debug
      

      return
      end
